@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@
 #include "simplestringlisteditor.h"
 
 #include <QInputDialog>
-#include <kiconloader.h>
 #include <QIcon>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -58,14 +57,28 @@ public:
     {
     }
 
+    QList<QListWidgetItem *> selectedItems() const
+    {
+        QList<QListWidgetItem *> listWidgetItem;
+        const int numberOfFilters = mListBox->count();
+        for (int i = 0; i < numberOfFilters; ++i) {
+            if (mListBox->item(i)->isSelected()) {
+                listWidgetItem << mListBox->item(i);
+            }
+        }
+        return listWidgetItem;
+    }
+
     QListWidget *mListBox = nullptr;
     QPushButton *mAddButton = nullptr;
     QPushButton *mRemoveButton = nullptr;
     QPushButton *mModifyButton = nullptr;
     QPushButton *mUpButton = nullptr;
     QPushButton *mDownButton = nullptr;
+    QPushButton *mCustomButton = nullptr;
     QVBoxLayout *mButtonLayout = nullptr;
     QString mAddDialogLabel;
+    QString mRemoveDialogLabel;
 };
 
 SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode buttons, const QString &addLabel, const QString &removeLabel, const QString &modifyLabel, const QString &addDialogLabel)
@@ -136,7 +149,6 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
         }
         d->mUpButton = new QPushButton(QString(), this);
         d->mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
-        d->mUpButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
         d->mUpButton->setAutoDefault(false);
         d->mUpButton->setEnabled(false);   // no selection yet
         d->mButtonLayout->addWidget(d->mUpButton);
@@ -150,13 +162,20 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
         }
         d->mDownButton = new QPushButton(QString(), this);
         d->mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-        d->mDownButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
         d->mDownButton->setAutoDefault(false);
         d->mDownButton->setEnabled(false);   // no selection yet
         d->mButtonLayout->addWidget(d->mDownButton);
         connect(d->mDownButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotDown);
     }
 
+    if (buttons & Custom) {
+        d->mCustomButton = new QPushButton(i18n("&Customize..."), this);
+        d->mCustomButton->setAutoDefault(false);
+        d->mCustomButton->setEnabled(false);   // no selection yet
+        d->mButtonLayout->addWidget(d->mCustomButton);
+        connect(d->mCustomButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotCustomize);
+    }
+
     d->mButtonLayout->addStretch(1);   // spacer
 
     connect(d->mListBox, &QListWidget::currentItemChanged, this, &SimpleStringListEditor::slotSelectionChanged);
@@ -232,6 +251,12 @@ void SimpleStringListEditor::setButtonText(ButtonCode button, const QString &tex
         }
         d->mModifyButton->setText(text);
         return;
+    case Custom:
+        if (!d->mCustomButton) {
+            break;
+        }
+        d->mCustomButton->setText(text);
+        return;
     case Up:
     case Down:
         qCDebug(PIMCOMMON_LOG) << "SimpleStringListEditor: Cannot change text of"
@@ -277,13 +302,32 @@ void SimpleStringListEditor::slotAdd()
     addNewEntry();
 }
 
+void SimpleStringListEditor::slotCustomize()
+{
+    QListWidgetItem *item = d->mListBox->currentItem();
+    if (!item) {
+        return;
+    }
+    const QString newText = customEntry(item->text());
+    if (!newText.isEmpty()) {
+        item->setText(newText);
+        Q_EMIT changed();
+    }
+}
+
+QString SimpleStringListEditor::customEntry(const QString &text)
+{
+    Q_UNUSED(text);
+    return {};
+}
+
 void SimpleStringListEditor::slotRemove()
 {
     const QList<QListWidgetItem *> selectedItems = d->mListBox->selectedItems();
     if (selectedItems.isEmpty()) {
         return;
     }
-    if (KMessageBox::Yes == KMessageBox::warningYesNo(this, i18n("Do you want to remove selected text?"), i18n("Remove"))) {
+    if (KMessageBox::Yes == KMessageBox::warningYesNo(this, d->mRemoveDialogLabel, i18n("Remove"))) {
         for (QListWidgetItem *item : selectedItems) {
             delete d->mListBox->takeItem(d->mListBox->row(item));
         }
@@ -320,16 +364,9 @@ void SimpleStringListEditor::slotModify()
     }
 }
 
-QList<QListWidgetItem *> SimpleStringListEditor::selectedItems() const
+void SimpleStringListEditor::setRemoveDialogLabel(const QString &removeDialogLabel)
 {
-    QList<QListWidgetItem *> listWidgetItem;
-    const int numberOfFilters = d->mListBox->count();
-    for (int i = 0; i < numberOfFilters; ++i) {
-        if (d->mListBox->item(i)->isSelected()) {
-            listWidgetItem << d->mListBox->item(i);
-        }
-    }
-    return listWidgetItem;
+    d->mRemoveDialogLabel = removeDialogLabel.isEmpty() ? i18n("Do you want to remove selected text?") : removeDialogLabel;
 }
 
 void SimpleStringListEditor::setAddDialogLabel(const QString &addDialogLabel)
@@ -339,7 +376,7 @@ void SimpleStringListEditor::setAddDialogLabel(const QString &addDialogLabel)
 
 void SimpleStringListEditor::slotUp()
 {
-    QList<QListWidgetItem *> listWidgetItem = selectedItems();
+    QList<QListWidgetItem *> listWidgetItem = d->selectedItems();
     if (listWidgetItem.isEmpty()) {
         return;
     }
@@ -370,7 +407,7 @@ void SimpleStringListEditor::slotUp()
 
 void SimpleStringListEditor::slotDown()
 {
-    QList<QListWidgetItem *> listWidgetItem = selectedItems();
+    QList<QListWidgetItem *> listWidgetItem = d->selectedItems();
     if (listWidgetItem.isEmpty()) {
         return;
     }
@@ -402,13 +439,14 @@ void SimpleStringListEditor::slotDown()
 
 void SimpleStringListEditor::slotSelectionChanged()
 {
-    QList<QListWidgetItem *> lstSelectedItems = d->mListBox->selectedItems();
+    const QList<QListWidgetItem *> lstSelectedItems = d->mListBox->selectedItems();
     const int numberOfItemSelected(lstSelectedItems.count());
     const bool uniqItemSelected = (numberOfItemSelected == 1);
+    const bool aItemIsSelected = !lstSelectedItems.isEmpty();
     // if there is one, item will be non-null (ie. true), else 0
     // (ie. false):
     if (d->mRemoveButton) {
-        d->mRemoveButton->setEnabled(!lstSelectedItems.isEmpty());
+        d->mRemoveButton->setEnabled(aItemIsSelected);
     }
 
     if (d->mModifyButton) {
@@ -417,11 +455,14 @@ void SimpleStringListEditor::slotSelectionChanged()
 
     const int currentIndex = d->mListBox->currentRow();
 
-    const bool aItemIsSelected = !lstSelectedItems.isEmpty();
     const bool allItemSelected = (d->mListBox->count() == numberOfItemSelected);
     const bool theLast = (currentIndex >= d->mListBox->count() - 1);
     const bool theFirst = (currentIndex == 0);
 
+    if (d->mCustomButton) {
+        d->mCustomButton->setEnabled(uniqItemSelected);
+    }
+
     if (d->mUpButton) {
         d->mUpButton->setEnabled(aItemIsSelected && ((uniqItemSelected && !theFirst)
                                                      || (!uniqItemSelected)) && !allItemSelected);
